@@ -14,12 +14,18 @@
 #' @param vartype Report variability as one or more of: standard error ("se", default),
 #'                confidence interval ("ci"), variance ("var") or coefficient of variation
 #'                ("cv").
-#' @param level A single number or vector of numbers indicating the confidence level
+#' @param level (For vartype = "ci" only) A single number or vector of numbers indicating
+#'              the confidence level
 #' @param proportion Use methods to calculate the proportion that may have more accurate
 #'                   confidence intervals near 0 and 1. Based on
 #'                   \code{\link[survey]{svyciprop}}.
 #' @param prop_method Type of proportion method to use if proportion is \code{TRUE}. See
 #'                    \code{\link[survey]{svyciprop}} for details.
+#' @param deff A logical value to indicate whether the design effect should be returned.
+#' @param df (For vartype = "ci" only) A numeric value indicating the degrees of freedom
+#'           for t-distribution. The default (NULL) uses \code{\link[survey]{degf}},
+#'           but Inf is the usual survey package's default (except in
+#'           \code{\link[survey]{svyciprop}}.
 #' @param ... Ignored
 #' @examples
 #' library(survey)
@@ -41,7 +47,7 @@
 #'   group_by(awards) %>%
 #'   summarise(pct = survey_mean())
 #'
-#' # Setting proportion = TRUE uses another method for calculating confidence intervals
+#' # Setting proportion = TRUE uses a different method for calculating confidence intervals
 #' dstrata %>%
 #'   summarise(high_api = survey_mean(api00 > 875, proportion = TRUE, vartype = "ci"))
 #'
@@ -49,11 +55,22 @@
 #' dstrata %>%
 #'   summarise(api99 = survey_mean(api99, vartype = "ci", level = c(0.95, 0.65)))
 #'
+#' # Note that the default degrees of freedom in srvyr is different from
+#' # survey, so your confidence intervals might not be exact matches. To
+#' # Replicate survey's behavior, use df = Inf
+#' dstrata %>%
+#'   summarise(srvyr_default = survey_mean(api99, vartype = "ci"),
+#'             survey_defualt = survey_mean(api99, vartype = "ci", df = Inf))
+#'
+#' comparison <- survey::svymean(~api99, dstrata)
+#' confint(comparison) # survey's default
+#' confint(comparison, df = survey::degf(dstrata)) # srvyr's default
+#'
 #' @export
 survey_mean <- function(x, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"),
                         level = 0.95, proportion = FALSE,
                         prop_method = c("logit", "likelihood", "asin", "beta",
-                                        "mean"), ...) {
+                                        "mean"), deff = FALSE, df = NULL, ...) {
   args <- list(...)
   if (!".svy" %in% names(args)) {
     stop_direct_call("survey_mean")
@@ -65,10 +82,12 @@ survey_mean <- function(x, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"),
   if (missing(prop_method)) prop_method <- "logit"
   prop_method <- match.arg(prop_method, several.ok = TRUE)
 
+  if (is.null(df)) df <- survey::degf(.svy)
+
   if (inherits(.svy, "grouped_svy")) {
-    survey_mean_grouped_svy(.svy, x, na.rm, vartype, level, proportion, prop_method)
+    survey_mean_grouped_svy(.svy, x, na.rm, vartype, level, deff, df, proportion, prop_method)
   } else if (inherits(.svy, "tbl_svy")) {
-    survey_mean_tbl_svy(.svy, x, na.rm, vartype, level, proportion, prop_method)
+    survey_mean_tbl_svy(.svy, x, na.rm, vartype, level, deff, df, proportion, prop_method)
   } else {
     stop_fake_method("survey_mean", class(.svy))
   }
@@ -76,30 +95,32 @@ survey_mean <- function(x, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"),
 
 survey_mean_tbl_svy <- function(.svy, x, na.rm = FALSE,
                                 vartype = c("se", "ci", "var", "cv"),
-                                level = 0.95, proportion = FALSE,
+                                level = 0.95, deff = FALSE, df = survey::degf(.svy),
+                                proportion = FALSE,
                                 prop_method = c("logit", "likelihood", "asin",
                                                 "beta", "mean")) {
 
   if (!proportion) {
-    survey_stat_ungrouped(.svy, survey::svymean, x, na.rm, vartype, level)
+    survey_stat_ungrouped(.svy, survey::svymean, x, na.rm, vartype, level, deff, df)
   } else {
     # survey::ciprop only accepts formulas so can't use main function
-    survey_stat_proportion(.svy, x, na.rm, vartype, level, prop_method)
+    survey_stat_proportion(.svy, x, na.rm, vartype, level, prop_method, df)
   }
 }
 
 survey_mean_grouped_svy <- function(.svy, x, na.rm = FALSE,
                                     vartype = c("se", "ci", "var", "cv"),
-                                    level = 0.95, proportion = FALSE,
+                                    level = 0.95, deff = FALSE, df = survey::degf(.svy),
+                                    proportion = FALSE,
                                     prop_method = c("logit", "likelihood",
                                                     "asin", "beta", "mean")) {
   if (missing(x)) {
     if (proportion) stop("proportion does not work with factors.")
-    survey_stat_factor(.svy, survey::svymean, na.rm, vartype, level)
+    survey_stat_factor(.svy, survey::svymean, na.rm, vartype, level, deff, df)
   } else if (proportion) {
     survey_stat_grouped(.svy, survey::svyciprop, x, na.rm, vartype, level,
-                        prop_method)
-  } else survey_stat_grouped(.svy, survey::svymean, x, na.rm, vartype, level)
+                        deff = FALSE, df, prop_method)
+  } else survey_stat_grouped(.svy, survey::svymean, x, na.rm, vartype, level, deff, df)
 }
 
 
@@ -115,6 +136,10 @@ survey_mean_grouped_svy <- function(.svy, x, na.rm = FALSE,
 #'                confidence interval ("ci"), variance ("var") or coefficient of variation
 #'                ("cv").
 #' @param level A single number or vector of numbers indicating the confidence level
+#' @param deff A logical value to indicate whether the design effect should be returned.
+#' @param df (For vartype = "ci" only) A numeric value indicating the degrees of freedom
+#'           for t-distribution. The default (NULL) uses \code{\link[survey]{degf}},
+#'           but Inf is the usual survey package's default.
 #' @param ... Ignored
 #' @examples
 #' library(survey)
@@ -140,9 +165,20 @@ survey_mean_grouped_svy <- function(.svy, x, na.rm = FALSE,
 #' dstrata %>%
 #'   summarise(enroll = survey_total(enroll, vartype = "ci", level = c(0.95, 0.65)))
 #'
+#' # Note that the default degrees of freedom in srvyr is different from
+#' # survey, so your confidence intervals might not exactly match. To
+#' # replicate survey's behavior, use df = Inf
+#' dstrata %>%
+#'   summarise(srvyr_default = survey_total(api99, vartype = "ci"),
+#'             survey_defualt = survey_total(api99, vartype = "ci", df = Inf))
+#'
+#' comparison <- survey::svytotal(~api99, dstrata)
+#' confint(comparison) # survey's default
+#' confint(comparison, df = survey::degf(dstrata)) # srvyr's default
+#'
 #' @export
 survey_total <- function(x = NULL, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"),
-                         level = 0.95, ...) {
+                         level = 0.95, deff = FALSE, df = NULL, ...) {
   args <- list(...)
   if (!".svy" %in% names(args)) {
     stop_direct_call("survey_total")
@@ -152,10 +188,12 @@ survey_total <- function(x = NULL, na.rm = FALSE, vartype = c("se", "ci", "var",
   if (missing(vartype)) vartype <- "se"
   vartype <- match.arg(vartype, several.ok = TRUE)
 
+  if (is.null(df)) df <- survey::degf(.svy)
+
   if (inherits(.svy, "grouped_svy")) {
-    survey_total_grouped_svy(.svy, x, na.rm, vartype, level)
+    survey_total_grouped_svy(.svy, x, na.rm, vartype, level, deff, df)
   } else if (inherits(.svy, "tbl_svy")) {
-    survey_total_tbl_svy(.svy, x, na.rm, vartype, level)
+    survey_total_tbl_svy(.svy, x, na.rm, vartype, level, deff, df)
   } else {
     stop_fake_method("survey_total", class(.svy))
   }
@@ -163,16 +201,18 @@ survey_total <- function(x = NULL, na.rm = FALSE, vartype = c("se", "ci", "var",
 
 survey_total_tbl_svy <- function(.svy, x, na.rm = FALSE,
                                  vartype = c("se", "ci", "var", "cv"),
-                                 level = 0.95) {
-  survey_stat_ungrouped(.svy, survey::svytotal, x, na.rm, vartype, level)
+                                 level = 0.95, deff = FALSE,
+                                 df = survey::degf(.svy)) {
+  survey_stat_ungrouped(.svy, survey::svytotal, x, na.rm, vartype, level, deff, df)
 }
 
 survey_total_grouped_svy <- function(.svy, x, na.rm = FALSE,
                                      vartype = c("se", "ci", "var", "cv"),
-                                     level = 0.95) {
+                                     level = 0.95, deff = FALSE,
+                                     df = survey::degf(.svy)) {
   if (!is.null(x)) survey_stat_grouped(.svy, survey::svytotal, x, na.rm,
-                                       vartype, level)
-  else survey_stat_factor(.svy, survey::svytotal, na.rm, vartype, level)
+                                       vartype, level, deff, df)
+  else survey_stat_factor(.svy, survey::svytotal, na.rm, vartype, level, deff, df)
 }
 
 
@@ -189,6 +229,11 @@ survey_total_grouped_svy <- function(.svy, x, na.rm = FALSE,
 #'                confidence interval ("ci"), variance ("var") or coefficient of variation
 #'                ("cv").
 #' @param level A single number or vector of numbers indicating the confidence level
+#' @param deff A logical value to indicate whether the design effect should be returned.
+#' @param df (For vartype = "ci" only) A numeric value indicating the degrees of freedom
+#'           for t-distribution. The default (NULL) uses \code{\link[survey]{degf}},
+#'           but Inf is the usual survey package's default (except in
+#'           \code{\link[survey]{svyciprop}}.
 #' @param ... Ignored
 #' @examples
 #' library(survey)
@@ -208,10 +253,21 @@ survey_total_grouped_svy <- function(.svy, x, na.rm = FALSE,
 #' dstrata %>%
 #'   summarise(enroll = survey_ratio(api99, api00, vartype = "ci", level = c(0.95, 0.65)))
 #'
+#' # Note that the default degrees of freedom in srvyr is different from
+#' # survey, so your confidence intervals might not exactly match. To
+#' # replicate survey's behavior, use df = Inf
+#' dstrata %>%
+#'   summarise(srvyr_default = survey_total(api99, vartype = "ci"),
+#'             survey_defualt = survey_total(api99, vartype = "ci", df = Inf))
+#'
+#' comparison <- survey::svytotal(~api99, dstrata)
+#' confint(comparison) # survey's default
+#' confint(comparison, df = survey::degf(dstrata)) # srvyr's default
+#'
 #' @export
 survey_ratio <- function(numerator, denominator, na.rm = FALSE,
                          vartype = c("se", "ci", "var", "cv"),
-                         level = 0.95, ...) {
+                         level = 0.95, deff = FALSE, df = NULL, ...) {
   args <- list(...)
   if (!".svy" %in% names(args)) {
     stop_direct_call("survey_ratio")
@@ -221,10 +277,12 @@ survey_ratio <- function(numerator, denominator, na.rm = FALSE,
   if (missing(vartype)) vartype <- "se"
   vartype <- match.arg(vartype, several.ok = TRUE)
 
+  if (is.null(df)) df <- survey::degf(.svy)
+
   if (inherits(.svy, "grouped_svy")) {
-    survey_ratio_grouped_svy(.svy, numerator, denominator, na.rm, vartype, level)
+    survey_ratio_grouped_svy(.svy, numerator, denominator, na.rm, vartype, level, deff, df)
   } else if (inherits(.svy, "tbl_svy")) {
-    survey_ratio_tbl_svy(.svy, numerator, denominator, na.rm, vartype, level)
+    survey_ratio_tbl_svy(.svy, numerator, denominator, na.rm, vartype, level, deff, df)
   } else {
     stop_fake_method("survey_ratio", class(.svy))
   }
@@ -233,20 +291,24 @@ survey_ratio <- function(numerator, denominator, na.rm = FALSE,
 
 survey_ratio_tbl_svy <- function(.svy, numerator, denominator, na.rm = FALSE,
                                  vartype = c("se", "ci", "var", "cv"),
-                                 level = 0.95) {
+                                 level = 0.95, deff = FALSE,
+                                 df = survey::degf(.svy)) {
 
   vartype <- c("coef", vartype)
-  stat <- survey::svyratio(data.frame(numerator), data.frame(denominator),
-                           .svy, na.rm = na.rm)
+  if (deff) vartype <- c(vartype, "deff")
 
-  out <- get_var_est(stat, vartype, level = level)
-  out
+  stat <- survey::svyratio(data.frame(numerator), data.frame(denominator),
+                           .svy, na.rm = na.rm, deff = deff, df = df)
+
+  out <- get_var_est(stat, vartype, level = level, df = df)
+  dplyr::bind_cols(out)
 }
 
 survey_ratio_grouped_svy <- function(.svy, numerator, denominator,
                                      na.rm = FALSE,
                                      vartype = c("se", "ci", "var", "cv"),
-                                     level = 0.95) {
+                                     level = 0.95, deff = FALSE,
+                                     df = survey::degf(.svy)) {
 
   grps <- survey::make.formula(groups(.svy))
 
@@ -262,15 +324,16 @@ survey_ratio_grouped_svy <- function(.svy, numerator, denominator,
   }
 
   stat <- survey::svyby(~`___numerator`, grps, .svy, survey::svyratio,
-                       denominator = ~`___denominator`,
-                       na.rm = na.rm, ci = TRUE)
+                        denominator = ~`___denominator`,
+                        na.rm = na.rm, ci = TRUE, deff = deff)
 
   vartype <- c("grps", "coef", vartype)
+  if (deff) vartype <- c(vartype, "deff")
 
   out <- get_var_est(stat, vartype, grps = as.character(groups(.svy)),
-                     level = level)
+                     level = level, df = df)
 
-  out
+  dplyr::bind_cols(out)
 }
 
 #' Calculate the quantile and its variation using survey methods
@@ -290,6 +353,9 @@ survey_ratio_grouped_svy <- function(.svy, numerator, denominator,
 #' @param f See \code{\link[stats]{approxfun}}
 #' @param interval_type See \code{\link[survey]{svyquantile}}
 #' @param ties See \code{\link[survey]{svyquantile}}
+#' @param df A number indicating the degrees of freedom for t-distribution. The
+#'           default, Inf uses the normal distribution (matches the survey package).
+#'           Also, has no effect for \code{type = "betaWald"}.
 #' @param ... Ignored
 #' @examples
 #' library(survey)
@@ -311,7 +377,7 @@ survey_quantile <- function(x, quantiles, na.rm = FALSE,
                             vartype = c("none", "se", "ci"),
                             level = 0.95, q_method = "linear", f = 1,
                             interval_type = c("Wald", "score", "betaWald"),
-                            ties = c("discrete", "rounded"), ...) {
+                            ties = c("discrete", "rounded"), df = Inf, ...) {
   args <- list(...)
   if (!".svy" %in% names(args)) {
     stop_direct_call("survey_quantile")
@@ -332,10 +398,10 @@ survey_quantile <- function(x, quantiles, na.rm = FALSE,
 
   if (inherits(.svy, "grouped_svy")) {
     survey_quantile_grouped_svy(.svy, x, quantiles, na.rm, vartype, level, q_method, f,
-                                interval_type, ties)
+                                interval_type, ties, df)
   } else if (inherits(.svy, "tbl_svy")) {
     survey_quantile_tbl_svy(.svy, x, quantiles, na.rm, vartype, level, q_method, f,
-                            interval_type, ties)
+                            interval_type, ties, df)
   } else {
     stop_fake_method("survey_quantile", class(.svy))
   }
@@ -346,22 +412,29 @@ survey_quantile_tbl_svy <- function(.svy, x, quantiles, na.rm = FALSE,
                                     level = 0.95, q_method = "linear", f = 1,
                                     interval_type = c("Wald", "score",
                                                       "betaWald"),
-                                    ties = c("discrete", "rounded")) {
+                                    ties = c("discrete", "rounded"),
+                                    df = Inf) {
 
   vartype <- setdiff(vartype, "none")
   vartype <- c("coef", vartype)
 
+  # Because of machine precision issues, 1 - 0.95 != 0.05...
+  # Here's a hacky way to force it, though it technically limits
+  # us to 7 digits of precision in alpha (seems like enough,
+  # we could go higher, but I worry about 32bit vs 64bit systems)
+  alpha = round(1 - level, 7)
+
   stat <- survey::svyquantile(data.frame(x), .svy,
-                      quantiles = quantiles, na.rm = na.rm,
-                      ci = TRUE, level = level, method = q_method, f = f,
-                      interval.type = interval_type, ties = ties)
+                              quantiles = quantiles, na.rm = na.rm,
+                              ci = TRUE, alpha = alpha, method = q_method, f = f,
+                              interval.type = interval_type, ties = ties, df = df)
 
   q_text <- paste0("_q", gsub("\\.", "", formatC(quantiles * 100, width = 2,
                                                  flag = "0")))
 
   out <- get_var_est(stat, vartype, var_names = q_text, level = level,
                      quantile = TRUE)
-  out
+  dplyr::bind_cols(out)
 }
 
 survey_quantile_grouped_svy <- function(.svy, x, quantiles, na.rm = FALSE,
@@ -370,9 +443,18 @@ survey_quantile_grouped_svy <- function(.svy, x, quantiles, na.rm = FALSE,
                                         f = 1,
                                         interval_type = c("Wald", "score",
                                                           "betaWald"),
-                                        ties = c("discrete", "rounded")) {
+                                        ties = c("discrete", "rounded"),
+                                        df = Inf) {
+
+
+  if (vartype == "none") {
+    vartype <- "se"
+    remove_se <- TRUE
+  } else {
+    vartype <- setdiff(vartype, "none")
+    remove_se <- FALSE
+  }
 
-  vartype <- setdiff(vartype, "none")
 
   grps <- survey::make.formula(groups(.svy))
 
@@ -384,18 +466,28 @@ survey_quantile_grouped_svy <- function(.svy, x, quantiles, na.rm = FALSE,
     .svy$phase1$sample$variables <- .svy$variables
   }
 
+  # Because of machine precision issues, 1 - 0.95 != 0.05...
+  # Here's a hacky way to force it, though it technically limits
+  # us to 7 digits of precision in alpha (seems like enough,
+  # we could go higher, but I worry about 32bit vs 64bit systems)
+  alpha = round(1 - level, 7)
+
   stat <- survey::svyby(formula = ~`___arg`, grps, .svy, survey::svyquantile,
-                      quantiles = quantiles, na.rm = na.rm,
-                      ci = TRUE, level = level, method = q_method,
-                      f = f, interval.type = interval_type, ties = ties)
+                        quantiles = quantiles, na.rm = na.rm,
+                        ci = TRUE, alpha = alpha, method = q_method,
+                        f = f, interval.type = interval_type, ties = ties,
+                        df = df, vartype = vartype)
 
   q_text <- paste0("_q", gsub("\\.", "", formatC(quantiles * 100, width = 2,
                                                  flag = "0")))
   vartype <- c("grps", "coef", vartype)
-  out <- get_var_est(stat, vartype, var_names = q_text,
-                     grps = as.character(groups(.svy)), level = level)
+  vartype[vartype == "ci"] <- "ci-prop"
 
-  out
+  out <- get_var_est(stat, vartype, var_names = q_text,
+                     grps = as.character(groups(.svy)), level = level,
+                     quantile = TRUE)
+
+  dplyr::bind_cols(out)
 }
 
 
@@ -406,7 +498,8 @@ survey_median <- function(x, na.rm = FALSE,
                           level = 0.95, q_method = "linear", f = 1,
                           interval_type = c("Wald", "score",
                                             "betaWald"),
-                          ties = c("discrete", "rounded"), ...) {
+                          ties = c("discrete", "rounded"), df = Inf,
+                          ...) {
 
   args <- list(...)
   if (!".svy" %in% names(args)) {
@@ -428,7 +521,8 @@ survey_median <- function(x, na.rm = FALSE,
 
   survey_quantile(x, quantiles = 0.5, na.rm = na.rm, vartype = vartype,
                   level = level, q_method = q_method, f = f,
-                  interval_type = interval_type, ties = ties, .svy = .svy)
+                  interval_type = interval_type, ties = ties,
+                  df = df, .svy = .svy)
 }
 
 #' Calculate the an unweighted summary statistic from a survey
@@ -469,22 +563,23 @@ unweighted <- function(x, ...) {
 }
 
 
-survey_stat_ungrouped <- function(.svy, func, x, na.rm, vartype, level) {
+survey_stat_ungrouped <- function(.svy, func, x, na.rm, vartype, level, deff, df) {
   if (class(x) == "factor") {
     stop(paste0("Factor not allowed in survey functions, should ",
                 "be used as a grouping variable"))
   }
   if (class(x) == "logical") x <- as.integer(x)
-  stat <- func(data.frame(x), .svy, na.rm = na.rm)
+  stat <- func(data.frame(x), .svy, na.rm = na.rm, deff = deff)
 
   vartype <- c("coef", vartype)
-  out <- get_var_est(stat, vartype, level = level)
+  if (deff) vartype <- c(vartype, "deff")
+  out <- get_var_est(stat, vartype, level = level, df = df)
 
-  out
+  dplyr::bind_cols(out)
 }
 
 survey_stat_grouped <- function(.svy, func, x, na.rm, vartype, level,
-                                prop_method = NULL) {
+                                deff, df, prop_method = NULL) {
   grps <- survey::make.formula(groups(.svy))
 
   if (class(x) == "factor") {
@@ -502,9 +597,10 @@ survey_stat_grouped <- function(.svy, func, x, na.rm, vartype, level,
     .svy$phase1$sample$variables <- .svy$variables
   }
   vartype <- c("grps", "coef", vartype)
+  if (deff) vartype = c(vartype, "deff")
 
   if (is.null(prop_method)) {
-    stat <- survey::svyby(~`___arg`, grps, .svy, func, na.rm = na.rm, se = TRUE)
+    stat <- survey::svyby(~`___arg`, grps, .svy, func, na.rm = na.rm, se = TRUE, deff = deff)
   } else {
     vartype[vartype == "ci"] <- "ci-prop"
     stat <- survey::svyby(~`___arg`, grps, .svy, func, na.rm = na.rm,
@@ -513,16 +609,17 @@ survey_stat_grouped <- function(.svy, func, x, na.rm, vartype, level,
   }
 
   out <- get_var_est(stat, vartype, grps = as.character(groups(.svy)),
-                     level = level)
-  out
+                     level = level, df = df)
+  dplyr::bind_cols(out)
 }
 
-survey_stat_factor <- function(.svy, func, na.rm, vartype, level) {
+survey_stat_factor <- function(.svy, func, na.rm, vartype, level, deff, df) {
   grps <- as.character(groups(.svy))
   peel <- grps[length(grps)]
   grps <- setdiff(grps, peel)
 
   vartype <- c("coef", vartype)
+  if (deff) vartype <- c(vartype, "deff")
 
   if (length(level) > 1) {
     warning("Only the first confidence level will be used")
@@ -532,7 +629,7 @@ survey_stat_factor <- function(.svy, func, na.rm, vartype, level) {
   if (length(grps) > 0) {
     stat <- survey::svyby(survey::make.formula(peel),
                           survey::make.formula(grps),
-                          .svy, func, na.rm = na.rm, se = TRUE)
+                          .svy, func, na.rm = na.rm, se = TRUE, deff = deff)
 
     var_names <- attr(stat, "svyby")[["variables"]]
     var_names <- unlist(lapply(var_names,
@@ -541,38 +638,41 @@ survey_stat_factor <- function(.svy, func, na.rm, vartype, level) {
     vartype <- c("grps", vartype)
 
     out <- get_var_est(stat, vartype, var_names = var_names, grps = grps,
-                       level = level)
+                       level = level, df = df)
+    # out <- dplyr::bind_cols(out)
+    names(out) <- vartype
     peel_levels <- levels(.svy[["variables"]][[peel]])
-    out <- factor_stat_reshape(out, grps, peel, var_names, peel_levels)
+    out <- factor_stat_reshape(out, peel, var_names, peel_levels)
 
     out
   } else {
     # Needed because grouped don't usually have "coef"
     vartype <- c("lvls", vartype)
-    stat <- func(survey::make.formula(peel), .svy, na.rm = na.rm)
+    stat <- func(survey::make.formula(peel), .svy, na.rm = na.rm, deff = deff)
 
     out <- get_var_est(stat, vartype, peel = peel,
-                       peel_levels = levels(.svy[["variables"]][[peel]]))
+                       peel_levels = levels(.svy[["variables"]][[peel]]),
+                       df = df)
 
-    out
+    dplyr::bind_cols(out)
   }
 }
 
 survey_stat_proportion <- function(.svy, x, na.rm, vartype, level,
-                                   prop_method) {
+                                   prop_method, df) {
   .svy$variables["___arg"] <- x
   stat <- survey::svyciprop(~`___arg`, .svy, na.rm = na.rm, level = level,
                             method = prop_method)
 
   vartype <- c("coef", vartype)
 
-  out <- get_var_est(stat, vartype, quantile = TRUE)
-  out
+  out <- get_var_est(stat, vartype, quantile = TRUE, df = df)
+  dplyr::bind_cols(out)
 }
 
 get_var_est <- function(stat, vartype, var_names = "", grps = "",
                         peel = "", peel_levels = NULL, level = 0.95,
-                        quantile = FALSE) {
+                        quantile = FALSE, df = Inf) {
   out_width <- length(var_names)
   out <- lapply(vartype, function(vvv) {
     if (vvv == "coef") {
@@ -590,11 +690,11 @@ get_var_est <- function(stat, vartype, var_names = "", grps = "",
     } else if (vvv == "ci") {
       if (!quantile) {
         if (length(level)==1) {
-          ci <- data.frame(matrix(stats::confint(stat, level = level),
+          ci <- data.frame(matrix(stats::confint(stat, level = level, df = df),
                                   ncol = 2 * out_width))
           names(ci) <- c(paste0(var_names, "_low"), paste0(var_names, "_upp"))
         } else {
-          lci <- lapply(level, function(x) {as.data.frame(stats::confint(stat,level = x))})
+          lci <- lapply(level, function(x) {as.data.frame(stats::confint(stat,level = x, df = df))})
           ci <- dplyr::bind_cols(lci)
           names(ci) <- paste0(var_names,"_", c("low","upp"),rep(level,each=2)*100)
         }
@@ -616,6 +716,10 @@ get_var_est <- function(stat, vartype, var_names = "", grps = "",
       cv <- data.frame((matrix(survey::cv(stat), ncol = out_width)))
       names(cv) <- paste0(var_names, "_cv")
       cv
+    } else if (vvv == "deff") {
+      deff <- data.frame(matrix(survey::deff(stat), ncol = out_width))
+      names(deff) <- paste0(var_names, "_deff")
+      deff
     } else if (vvv == "grps") {
       stat[grps]
     } else if (vvv == "lvls") {
@@ -632,28 +736,42 @@ get_var_est <- function(stat, vartype, var_names = "", grps = "",
       lvls
     }
   })
-  dplyr::bind_cols(out)
 }
 
-# base reshape was difficult to work with, but might be worth reinvestigating
-# (or others, but have to weight the cost of extra dependency). This takes the
-# survey stat object that has the peel variable wide, and makes it long.
-factor_stat_reshape <- function(stat, grps, peel, var_names, peel_levels = NULL) {
-  out <- lapply(var_names, function(this_var) {
-    wide_names <- names(stat)[
-      grep(paste0("^", this_var, "(_se|_low|_upp|_var|_cv)?$"), names(stat))
-    ]
-    stat[[peel]] <- this_var
-    out <- stat[, c(grps, peel, wide_names)]
-    names(out)[names(out) %in% wide_names] <-
-      sub(this_var, "", names(out)[names(out) %in% wide_names])
 
-    out
+factor_stat_reshape <- function(stat, peel, var_names, peel_levels) {
+  out <- lapply(seq_along(stat), function(iii) {
+    stat_name <- names(stat)[iii]
+    stat_df <- stat[[iii]]
+    if (stat_name == "grps") {
+      stat_df <- dplyr::tbl_df(stat_df)
+      stat_df[rep(seq_len(nrow(stat_df)), length(var_names)), ]
+    } else if(stat_name == "ci") {
+      out <- utils::stack(stat_df)
+      out <- data.frame(
+        `_low` = out[substr_right(out$ind, 4) == "_low", "values"],
+        `_upp` = out[substr_right(out$ind, 4) == "_upp", "values"],
+        check.names = FALSE, stringsAsFactors = FALSE
+      )
+    } else if(stat_name == "coef") {
+      out <- utils::stack(stat_df)
+      names(out) <- c("", peel)
+      out[, c(2, 1)]
+    } else {
+      out <- utils::stack(stat_df)
+      out <- select_(out, "-ind")
+      names(out) <- paste0("_", stat_name)
+      out
+    }
   })
-  out <- dplyr::bind_rows(out)
+  out <- dplyr::bind_cols(out)
+
+  # peel's factor was created by stack, but is just alphabetic
+  out[[peel]] <- as.character(out[[peel]])
   if (!is.null(peel_levels)) {
     out[[peel]] <- factor(out[[peel]], peel_levels)
   }
+
   out
 }
 
