@@ -1,8 +1,10 @@
-context("Quick tests for added summary stats (ratio / quantile)")
+context("Quick tests for summary stats (ratio / quantile)")
 
 library(srvyr)
 library(survey)
 
+df_test <- 30
+
 data(api)
 dstrata <- apistrat %>%
   as_survey_design(strata = stype, weights = pw)
@@ -99,45 +101,108 @@ test_that(
 
 
 out_srvyr <- dstrata %>%
-  summarize(mn = survey_mean(api00, vartype = "ci", level = 0.9),
-            ratio = survey_ratio(api00, api99, vartype = "ci", level = 0.9),
+  summarize(ratio = survey_ratio(api00, api99, vartype = "ci", level = 0.9),
             mdn = survey_median(api00, vartype = "ci", level = 0.9)) %>%
-  select(-mn, -ratio, -mdn_q50) %>%
+  select(-ratio, -mdn_q50) %>%
   unlist()
 
-mn <- svymean(~api00, dstrata)
-mn <- confint(mn, level = 0.9)
 ratio <- svyratio(~api00, ~api99, dstrata)
-ratio <- confint(ratio, level = 0.9)
-mdn <- svyquantile(~api00, dstrata, quantile = 0.5, ci = TRUE, level = 0.9)
+ratio <- confint(ratio, level = 0.9, df = degf(dstrata))
+mdn <- svyquantile(~api00, dstrata, quantile = 0.5, ci = TRUE, alpha = 0.1)
 mdn <- confint(mdn)
-out_survey <- c(mn[1], mn[2], ratio[1], ratio[2], mdn[1], mdn[2])
-names(out_survey) <- c("mn_low", "mn_upp", "ratio_low",
-                       "ratio_upp", "mdn_q50_low", "mdn_q50_upp")
+out_survey <- c(ratio[1], ratio[2], mdn[1], mdn[2])
+names(out_survey) <- c("ratio_low", "ratio_upp", "mdn_q50_low", "mdn_q50_upp")
 
-test_that("mean/median/ratio with CIs respect level parameter (ungrouped)",
+test_that("median/ratio with CIs respect level parameter (ungrouped)",
           expect_equal(out_srvyr, out_survey))
 
 
 suppressWarnings(out_srvyr <- dstrata %>%
   group_by(stype) %>%
-  summarize(mn = survey_mean(api00, vartype = "ci", level = 0.9),
-            ratio = survey_ratio(api00, api99, vartype = "ci", level = 0.9),
+  summarize(ratio = survey_ratio(api00, api99, vartype = "ci", level = 0.9),
             mdn = survey_median(api00, vartype = "ci", level = 0.9)) %>%
-  select(-mn, -ratio, -mdn_q50, -stype)
+  select(-ratio, -mdn_q50, -stype)
 )
 
-mn <- svyby(~api00, ~stype, dstrata, svymean)
-mn <- confint(mn, level = 0.9)
 ratio <- svyby(~api00, ~stype, denominator = ~api99, dstrata, svyratio)
-ratio <- confint(ratio, level = 0.9)
-suppressWarnings(mdn <- svyby(~api00, ~stype, dstrata, svyquantile,
-                              quantile = 0.5, ci = TRUE, level = 0.90))
-mdn <- confint(mdn, level = 0.9)
-out_survey <- dplyr::bind_cols(data.frame(mn), data.frame(ratio),
-                               data.frame(mdn))
-names(out_survey) <- c("mn_low", "mn_upp", "ratio_low", "ratio_upp",
-                       "mdn_q50_low", "mdn_q50_upp")
+ratio <- confint(ratio, level = 0.9, df = degf(dstrata))
 
-test_that("mean/median/ratio with CIs respect level parameter (ungrouped)",
+suppressWarnings(mdn <- svyby(~api00, ~stype, dstrata, svyquantile,
+                              quantile = 0.5, ci = TRUE, alpha = 0.1, vartype = "ci") %>%
+  data.frame() %>%
+  select(-api00, -stype))
+
+out_survey <- dplyr::bind_cols(data.frame(ratio), mdn)
+names(out_survey) <- c("ratio_low", "ratio_upp", "mdn_q50_low", "mdn_q50_upp")
+
+test_that("median/ratio with CIs respect level parameter (grouped)",
           expect_equal(out_srvyr, out_survey))
+
+
+out_survey <- svyratio(~api99, ~api00, dstrata, deff = TRUE)
+
+out_srvyr <- dstrata %>%
+  summarise(survey_ratio = survey_ratio(api99, api00, deff = TRUE, vartype = "ci", df = df_test))
+
+test_that("deff works for ungrouped survey total",
+          expect_equal(c(out_survey[[1]], deff(out_survey)[[1]]),
+                       c(out_srvyr[["survey_ratio"]][[1]], out_srvyr[["survey_ratio_deff"]][[1]])))
+
+test_that("df works for ungrouped survey total",
+          expect_equal(confint(out_survey, df = df_test)[c(1, 2)],
+                       c(out_srvyr[["survey_ratio_low"]][[1]], out_srvyr[["survey_ratio_upp"]][[1]])))
+
+
+
+
+
+out_srvyr <- dstrata %>%
+  group_by(stype) %>%
+  summarise(survey_ratio = survey_ratio(api99, api00, deff = TRUE, vartype = "ci", df = df_test))
+
+temp_survey <- svyby(~api99, ~stype, dstrata, svyratio, deff = TRUE, vartype = c("se", "ci"),
+                     denominator = ~api00)
+out_survey <- temp_survey %>%
+  data.frame() %>%
+  dplyr::tbl_df() %>%
+  rename(survey_ratio = api99.api00, survey_ratio_low = ci_l, survey_ratio_upp = ci_u,
+         survey_ratio_deff = `DEff`) %>%
+  select(-se.api99.api00)
+
+out_survey[, c("survey_ratio_low", "survey_ratio_upp")] <-
+  confint(temp_survey, df = df_test)
+
+test_that("deff and df work for grouped survey total",
+          expect_equal(out_srvyr, out_survey))
+
+
+out_survey <- svyquantile(~api99, dstrata, c(0.5), ci = TRUE, df = df_test)
+
+out_srvyr <- dstrata %>%
+  summarise(survey = survey_median(api99, vartype = "ci", df = df_test))
+
+test_that("df works for ungrouped survey total",
+          expect_equal(confint(out_survey)[c(1, 2)],
+                       c(out_srvyr[["survey_q50_low"]][[1]], out_srvyr[["survey_q50_upp"]][[1]])))
+
+
+
+
+
+out_srvyr <- suppressWarnings(
+  dstrata %>%
+    group_by(stype) %>%
+    summarise(survey = survey_median(api99, vartype = "ci", df = df_test))
+)
+
+temp_survey <- suppressWarnings(svyby(~api99, ~stype, dstrata, svyquantile, quantiles = c(0.5), ci = TRUE,
+                     vartype = c("se", "ci"), df = df_test))
+out_survey <- temp_survey %>%
+  data.frame() %>%
+  dplyr::tbl_df() %>%
+  rename(survey_q50 = api99, survey_q50_low = ci_l, survey_q50_upp = ci_u) %>%
+  select(-se)
+
+test_that("df works for grouped survey quantile",
+          expect_equal(out_srvyr, out_survey))
+
